==> kubernetes-model-1.0.30-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class PersistentVolumeClaimVolumeSourceFluentImpl<T extends PersistentVolumeClaimVolumeSourceFluent<T>> extends BaseFluent<T> implements PersistentVolumeClaimVolumeSourceFluent<T>{

     String claimName;     Boolean readOnly;     Map<String, Object> additionalProperties = new HashMap();

    public String getClaimName(){
    return this.claimName;
    }
    public T withClaimName( String claimName){
    this.claimName=claimName; return (T) this;
    }
    public Boolean isReadOnly(){
    return this.readOnly;
    }
    public T withReadOnly( Boolean readOnly){
    this.readOnly=readOnly; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
PersistentVolumeClaimVolumeSourceFluentImpl that = (PersistentVolumeClaimVolumeSourceFluentImpl) o;
if (claimName != null ? !claimName.equals(that.claimName) :that.claimName != null) return false;
if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.31-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeClaimVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class PersistentVolumeClaimVolumeSourceFluentImpl<T extends PersistentVolumeClaimVolumeSourceFluent<T>> extends BaseFluent<T> implements PersistentVolumeClaimVolumeSourceFluent<T>{

     String claimName;     Boolean readOnly;     Map<String, Object> additionalProperties = new HashMap();

    public String getClaimName(){
    return this.claimName;
    }
    public T withClaimName( String claimName){
    this.claimName=claimName; return (T) this;
    }
    public Boolean isReadOnly(){
    return this.readOnly;
    }
    public T withReadOnly( Boolean readOnly){
    this.readOnly=readOnly; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
PersistentVolumeClaimVolumeSourceFluentImpl that = (PersistentVolumeClaimVolumeSourceFluentImpl) o;
if (claimName != null ? !claimName.equals(that.claimName) :that.claimName != null) return false;
if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
